@@ -61,13 +61,13 @@ namespace trng {
   }
 
   const lcg64_shift::parameter_type
-  lcg64_shift::Default=parameter_type(18145460002477866997ull, 1ull);
+  lcg64_shift::Default=parameter_type(18145460002477866997u, 1u);
   const lcg64_shift::parameter_type 
-  lcg64_shift::LEcuyer1=parameter_type(2862933555777941757ull, 1ull);
+  lcg64_shift::LEcuyer1=parameter_type(2862933555777941757u, 1u);
   const lcg64_shift::parameter_type 
-  lcg64_shift::LEcuyer2=parameter_type(3202034522624059733ull, 1ull);
+  lcg64_shift::LEcuyer2=parameter_type(3202034522624059733u, 1u);
   const lcg64_shift::parameter_type 
-  lcg64_shift::LEcuyer3=parameter_type(3935559000370003845ull, 1ull);
+  lcg64_shift::LEcuyer3=parameter_type(3935559000370003845u, 1u);
 
   // Random number engine concept
   lcg64_shift::lcg64_shift(lcg64_shift::parameter_type P) :
@@ -77,20 +77,22 @@ namespace trng {
     P(P), S() { 
     seed(s);
   }
+
+  lcg64_shift::lcg64_shift(unsigned long long s, lcg64_shift::parameter_type P) :
+    P(P), S() { 
+    seed(s);
+  }
     
   void lcg64_shift::seed() {
     (*this)=lcg64_shift();
   }
  
   void lcg64_shift::seed(unsigned long s) {
-    S.r=s;
+    S.r=static_cast<lcg64_shift::result_type>(s);
   }
   
-  void lcg64_shift::seed(lcg64_shift::result_type s) {
-    S.r=s;
-#if ULONG_LONG_MAX>18446744073709551615ull
-    S.r&=0xfffffffffffffffful;
-#endif
+  void lcg64_shift::seed(unsigned long long s) {
+    S.r=static_cast<lcg64_shift::result_type>(s);
   }
   
   // Equality comparable concept
