@@ -39,6 +39,7 @@
 #include <stdexcept>
 #include <trng/cuda.hpp>
 #include <trng/utility.hpp>
+#include <trng/int_types.hpp>
 #include <trng/int_math.hpp>
 
 namespace trng {
@@ -49,13 +50,13 @@ namespace trng {
   public:
   
     // Uniform random number generator concept
-    typedef long result_type;
+    typedef int32_t result_type;
     TRNG_CUDA_ENABLE
     result_type operator()();
   private:
-    static const result_type modulus=2147483647l;
-    static const result_type gen=123567893l;
-    static const result_type min_=0l;
+    static const result_type modulus=2147483647;
+    static const result_type gen=123567893;
+    static const result_type min_=0;
     static const result_type max_=modulus-1;
   public:
 #if __cplusplus>=201103L
@@ -187,14 +188,10 @@ namespace trng {
     void seed(unsigned long);
     template<typename gen>
     void seed(gen &g) {
-      result_type r1=static_cast<unsigned long>(g())%
-        static_cast<unsigned long>(modulus);
-      result_type r2=static_cast<unsigned long>(g())%
-        static_cast<unsigned long>(modulus);
-      result_type r3=static_cast<unsigned long>(g())%
-        static_cast<unsigned long>(modulus);
-      result_type r4=static_cast<unsigned long>(g())%
-        static_cast<unsigned long>(modulus);
+      result_type r1=static_cast<uint32_t>(g())%static_cast<uint32_t>(modulus);
+      result_type r2=static_cast<uint32_t>(g())%static_cast<uint32_t>(modulus);
+      result_type r3=static_cast<uint32_t>(g())%static_cast<uint32_t>(modulus);
+      result_type r4=static_cast<uint32_t>(g())%static_cast<uint32_t>(modulus);
       S.r1=r1;
       S.r2=r2;
       S.r3=r3;
@@ -268,14 +265,10 @@ namespace trng {
 
   TRNG_CUDA_ENABLE
   inline void yarn4::step() {
-    unsigned long long t(static_cast<unsigned long long>(P.a1)*
-			 static_cast<unsigned long long>(S.r1)+
-			 static_cast<unsigned long long>(P.a2)*
-			 static_cast<unsigned long long>(S.r2)+
-			 static_cast<unsigned long long>(P.a3)*
-			 static_cast<unsigned long long>(S.r3)+
-			 static_cast<unsigned long long>(P.a4)*
-			 static_cast<unsigned long long>(S.r4));
+    uint64_t t(static_cast<uint64_t>(P.a1)*static_cast<uint64_t>(S.r1)+
+	       static_cast<uint64_t>(P.a2)*static_cast<uint64_t>(S.r2)+
+	       static_cast<uint64_t>(P.a3)*static_cast<uint64_t>(S.r3)+
+	       static_cast<uint64_t>(P.a4)*static_cast<uint64_t>(S.r4));
     S.r4=S.r3;  S.r3=S.r2;  S.r2=S.r1;  S.r1=int_math::modulo<modulus, 4>(t);
   }
   
@@ -286,7 +279,7 @@ namespace trng {
     if (S.r1==0) 
       return 0;
     yarn4::result_type n=S.r1;
-    long long p(1ll), t(gen);
+    int64_t p(1), t(gen);
     while (n>0) {
       if ((n&0x1)==0x1)
 	p=int_math::modulo<modulus, 1>(p*t);
@@ -312,15 +305,15 @@ namespace trng {
       utility::throw_this(std::invalid_argument("invalid argument for trng::yarn4::split"));
 #endif
     if (s>1) {
-      jump(n+1);  long q0=S.r1;
-      jump(s);    long q1=S.r1;
-      jump(s);    long q2=S.r1;
-      jump(s);    long q3=S.r1;
-      jump(s);    long q4=S.r1;
-      jump(s);    long q5=S.r1;
-      jump(s);    long q6=S.r1;
-      jump(s);    long q7=S.r1;
-      long a[4], b[16];
+      jump(n+1);  int32_t q0=S.r1;
+      jump(s);    int32_t q1=S.r1;
+      jump(s);    int32_t q2=S.r1;
+      jump(s);    int32_t q3=S.r1;
+      jump(s);    int32_t q4=S.r1;
+      jump(s);    int32_t q5=S.r1;
+      jump(s);    int32_t q6=S.r1;
+      jump(s);    int32_t q7=S.r1;
+      int32_t a[4], b[16];
       a[ 0]=q4;  b[ 0]=q3;  b[ 1]=q2;  b[ 2]=q1;  b[ 3]=q0;
       a[ 1]=q5;  b[ 4]=q4;  b[ 5]=q3;  b[ 6]=q2;  b[ 7]=q1;
       a[ 2]=q6;  b[ 8]=q5;  b[ 9]=q4;  b[10]=q3;  b[11]=q2;
@@ -335,12 +328,12 @@ namespace trng {
   
   TRNG_CUDA_ENABLE
   inline void yarn4::jump2(unsigned int s) {
-    long b[16], c[16], d[4], r[4];
-    long t1(P.a1), t2(P.a2), t3(P.a3), t4(P.a4);
+    int32_t b[16], c[16], d[4], r[4];
+    int32_t t1(P.a1), t2(P.a2), t3(P.a3), t4(P.a4);
     b[ 0]=P.a1;  b[ 1]=P.a2;  b[ 2]=P.a3;  b[ 3]=P.a4;
-    b[ 4]=1l;    b[ 5]=0l;    b[ 6]=0l;    b[ 7]=0l;
-    b[ 8]=0l;    b[ 9]=1l;    b[10]=0l;    b[11]=0l;
-    b[12]=0l;    b[13]=0l;    b[14]=1l;    b[15]=0l;
+    b[ 4]=1;     b[ 5]=0;     b[ 6]=0;     b[ 7]=0; 
+    b[ 8]=0;     b[ 9]=1;     b[10]=0;     b[11]=0; 
+    b[12]=0;     b[13]=0;     b[14]=1;     b[15]=0; 
     for (unsigned int i(0); i<s; ++i)
       if ((i&1)==0)
 	int_math::matrix_mult<4>(b, b, c, modulus);
@@ -378,53 +371,39 @@ namespace trng {
 
   TRNG_CUDA_ENABLE
   inline void yarn4::backward() {
-    long t;
-    if (P.a4!=0l) {
+    result_type t;
+    if (P.a4!=0) {
       t=S.r1;
-      t-=static_cast<long>((static_cast<long long>(P.a1)*
-			    static_cast<long long>(S.r2))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a1)*static_cast<int64_t>(S.r2))%modulus);
+      if (t<0)
 	t+=modulus;
-      t-=static_cast<long>((static_cast<long long>(P.a2)*
-			    static_cast<long long>(S.r3))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a2)*static_cast<int64_t>(S.r3))%modulus);
+      if (t<0)
 	t+=modulus;
-      t-=static_cast<long>((static_cast<long long>(P.a3)*
-                          static_cast<long long>(S.r4))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a3)*static_cast<int64_t>(S.r4))%modulus);
+      if (t<0)
 	t+=modulus;
-      t=static_cast<long>((static_cast<long long>(t)*
-			   static_cast<long long>
-			   (int_math::modulo_invers(P.a4, modulus)))%modulus);
-    } else if (P.a3!=0l) {
+      t=static_cast<result_type>((static_cast<int64_t>(t)*static_cast<int64_t>(int_math::modulo_invers(P.a4, modulus)))%modulus);
+    } else if (P.a3!=0) {
       t=S.r2;
-      t-=static_cast<long>((static_cast<long long>(P.a1)*
-			    static_cast<long long>(S.r3))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a1)*static_cast<int64_t>(S.r3))%modulus);
+      if (t<0)
 	t+=modulus;
-      t-=static_cast<long>((static_cast<long long>(P.a2)*
-			    static_cast<long long>(S.r4))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a2)*static_cast<int64_t>(S.r4))%modulus);
+      if (t<0)
 	t+=modulus;
-      t=static_cast<long>((static_cast<long long>(t)*
-			   static_cast<long long>
-			   (int_math::modulo_invers(P.a3, modulus)))%modulus);
-    } else if (P.a2!=0l) {
+      t=static_cast<result_type>((static_cast<int64_t>(t)*static_cast<int64_t>(int_math::modulo_invers(P.a3, modulus)))%modulus);
+    } else if (P.a2!=0) {
       t=S.r3;
-      t-=static_cast<long>((static_cast<long long>(P.a1)*
-			    static_cast<long long>(S.r4))%modulus);
-      if (t<0l)
+      t-=static_cast<result_type>((static_cast<int64_t>(P.a1)*static_cast<int64_t>(S.r4))%modulus);
+      if (t<0)
 	t+=modulus;
-      t=static_cast<long>((static_cast<long long>(t)*
-			   static_cast<long long>
-			   (int_math::modulo_invers(P.a2, modulus)))%modulus);
-    } else if (P.a1!=0l) {
+      t=static_cast<result_type>((static_cast<int64_t>(t)*static_cast<int64_t>(int_math::modulo_invers(P.a2, modulus)))%modulus);
+    } else if (P.a1!=0) {
       t=S.r4;
-      t=static_cast<long>((static_cast<long long>(t)*
-			   static_cast<long long>
-			   (int_math::modulo_invers(P.a1, modulus)))%modulus);
+      t=static_cast<result_type>((static_cast<int64_t>(t)*static_cast<int64_t>(int_math::modulo_invers(P.a1, modulus)))%modulus);
     } else
-      t=0l;
+      t=0;
     S.r1=S.r2;  S.r2=S.r3;  S.r3=S.r4;  S.r4=t;
   }
 
